/*
    routines which actually draw the blocks of the cube. 
    Copyright (C) 1998  John Darrington

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
*/
#ifndef DRW_BLOCKS_H
#define DRW_BLOCKS_H

#include "cube.h"
#include <GL/gl.h>
#include "textures.h"

/* The texture names for each face */
extern struct pattern_parameters face_patterns[6] ; 

void draw_block(GLboolean highlight, int block_id);

void setColour(int i,
	       GLfloat red,
	       GLfloat green, 
	       GLfloat  blue);

void getColour(int i, GLfloat *red, GLfloat *green, GLfloat *blue) ;


#endif
